Base Modules
============

These modules define `algotradepy`'s interface. Any extension to the library
must implement them.

.. toctree::
   :maxdepth: 2

   base_broker
   base_provider
   base_streamer
